@@ -1,4 +1,6 @@
 """Command-line interface."""
+import sys
+
 import click
 
 import ncdump_rich.ncdump as ncd
@@ -7,7 +9,9 @@ from . import __version__
 
 @click.command()
 @click.version_option(version=__version__)
-@click.option("--input", "-i", type=str, help="File name.")
+@click.option(
+    "--input", "-i", type=click.Path(exists=True, readable=True), help="File name."
+)
 @click.option(
     "--long/--short",
     "-l/-s",
@@ -27,7 +31,10 @@ from . import __version__
 )
 def main(input: str, long: bool, format: bool) -> None:
     """Rich NcDump."""
-    ncd.ncdump(input, long=long, truecolor=format)
+    if input.endswith(".nc"):
+        ncd.ncdump(input, long=long, truecolor=format)
+    else:
+        sys.exit(f"ncdump-rich can only read .nc files, not {input.split('.')[-1]}")
 
 
 if __name__ == "__main__":
